@@ -1,5 +1,7 @@
 package Form::Factory::Action::Meta::Attribute::Control;
-our $VERSION = '0.019';
+BEGIN {
+  $Form::Factory::Action::Meta::Attribute::Control::VERSION = '0.020';
+}
 use Moose::Role;
 
 =head1 NAME
@@ -8,7 +10,7 @@ Form::Factory::Action::Meta::Attribute::Control - Form control attribute-traits
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 SYNOPSIS
 
@@ -115,20 +117,6 @@ around new => sub {
     $class->$next($name, %options);
 };
 
-=head2 legal_options_for_inheritance
-
-Modifies the L<Moose::Meta::Attribute> version to also allow L<features> to be modified.
-
-=cut
-
-around legal_options_for_inheritance => sub {
-    my $next    = shift;
-    my $self    = shift;
-    my @options = $self->$next(@_);
-    push @options, 'features', '__meta';
-    return @options;
-};
-
 =head2 clone_and_inherit_options
 
 Modifies the L<Moose::Meta::Attribute> version to handle the merging of L<features>.
@@ -170,7 +158,9 @@ it under the same terms as Perl itself.
 =cut
 
 package Moose::Meta::Attribute::Custom::Trait::Form::Control;
-our $VERSION = '0.019';
+BEGIN {
+  $Moose::Meta::Attribute::Custom::Trait::Form::Control::VERSION = '0.020';
+}
 sub register_implementation { 'Form::Factory::Action::Meta::Attribute::Control' }
 
 1;
\ No newline at end of file
